:!+=============================================================================
:!
:! Name:        GetTaskList.bat
:! Type:        User Command Task
:! Language:    MS-DOS Batch
:! Index:       Generates a sorted task list into a file
:!
:!
:! Function:
:!
:!      This procedure is intended to be scheduled periodically, and its output 
:!      generated on different dates can be used by comparison to help determine 
:!      if something's running that didn't used to be running.  It's useful for 
:!      watching for malware and for keeping an eye on system performance.
:!
:!
:! Synopsis:
:!
:!      GetTaskList
:!
:!      <No arguments required>
:!
:!
:! Additional Information:
:!
:!      This procedure creates a file named for the current date and time, and
:!      located in your user profile folder under a Log subfolder 
:!      (e.g., C:\Users\username\Log).
:!
:!      The filename is formatted as follows:
:!
:!      TaskList_YYYY_MM_DD_HH_MM_SS.log
:!
:!-=============================================================================
:!
:!  Start of process.
:!
        SET EXIT_STATUS=0
:!
:!  Create the log folder if it doesn't exist.
:!
        MD "%USERPROFILE%\Log" >nul 2>&1
:!
:!  Craft the filename
:!
        SHOWTIME "SET _TL_Filename=TaskList_%%Y_%%m_%%d_%%H_%%M_%%S.log" >"%TEMP%\_TL_SetVar.bat"
        CALL "%TEMP%\_TL_SetVar.bat"
:!
        IF NOT "%_TL_Filename" == "" GOTO DO_TL
:!
        ECHO TaskList filename could not be generated.
        SET EXIT_STATUS=4
        GOTO END_OF_PROCEDURE
:!
:! = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
:!
:DO_TL
:!
        TaskList /SVC /FO:CSV >> "%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >> %USERPROFILE%\Log\%_TL_Filename% 2>&1
        TaskList /M /FO:CSV >> "%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >> %USERPROFILE%\Log\%_TL_Filename% 2>&1
        TaskList /V /FO:CSV >> "%USERPROFILE%\Log\%_TL_Filename%" 2>&1
:!
:! = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
:!
:END_OF_PROCEDURE
:!
        DEL /Q "%TEMP%\_TL_SetVar.bat" >nul 2>&1
        SET _TL_Filename=
        EXIT %EXIT_STATUS%
:!
:!==============================================================================
:!
:!  End of file.
:!
:!==============================================================================
